@@ -1,14 +1,14 @@
 # flake8: noqa
 
-__version__ = "1.2.4"
-
-# -----------------------------------------------------------------------------
+__version__ = "1.5.0"
 
 from . import _io as io
 from . import data
 from . import draw
 from .centerize import centerize
 from .color import asgray
+from .color import asrgb
+from .color import asrgba
 from .color import gray2rgb
 from .color import hsv2rgb
 from .color import rgb2gray
@@ -17,6 +17,8 @@ from .color import rgb2rgba
 from .color import rgba2rgb
 from .depth import Depth2RGB
 from .depth import depth2rgb
+from .dtype import bool2ubyte
+from .dtype import float2ubyte
 from .flow import flow2rgb
 from .instances import instances2rgb
 from .label import label2rgb
@@ -27,9 +29,3 @@ from .normalize import normalize
 from .resize import resize
 from .tile import tile
 from .trajectory import plot_trajectory
-
-# -----------------------------------------------------------------------------
-
-# visualization targets
-
-# visualization operations
